@@ -8,6 +8,7 @@ from typing import Union
 from livechat.agent.rtm.api.v33 import AgentRtmV33
 from livechat.agent.rtm.api.v34 import AgentRtmV34
 from livechat.agent.rtm.api.v35 import AgentRtmV35
+from livechat.agent.rtm.api.v36 import AgentRtmV36
 from livechat.config import CONFIG
 
 stable_version = CONFIG.get('stable')
@@ -37,6 +38,7 @@ class AgentRTM:
             '3.3': AgentRtmV33,
             '3.4': AgentRtmV34,
             '3.5': AgentRtmV35,
+            '3.6': AgentRtmV36,
         }.get(version)
         if not client:
             raise ValueError('Provided version does not exist.')
