@@ -1,5 +1,7 @@
 ''' Configuration API module with client class in version 3.5. '''
 
+from typing import List
+
 import httpx
 
 from livechat.utils.helpers import prepare_payload
@@ -397,8 +399,9 @@ class ConfigurationApiV35(HttpClient):
                    name: str = None,
                    avatar: str = None,
                    max_chats_count: int = None,
+                   default_group_priority: str = None,
+                   job_title: str = None,
                    groups: list = None,
-                   webhooks: dict = None,
                    work_scheduler: dict = None,
                    timezone: str = None,
                    owner_client_id: str = None,
@@ -409,8 +412,9 @@ class ConfigurationApiV35(HttpClient):
                 name (str): Display name.
                 avatar (str): Avatar URL.
                 max_chats_count (int): Max. number of incoming chats that can be routed to the Bot; default: 6.
+                default_group_priority (str): The default routing priority for a group without defined priority.
+                job_title (str): Bot's job title.
                 groups (list): Groups the Bot belongs to.
-                webhooks (dict): Webhooks sent to the Bot.
                 work_scheduler (dict): Work scheduler options to set for the new Bot.
                 timezone (str): The time zone in which the Bot's work scheduler should operate.
                 owner_client_id (str): ID of the client bot will be assigned to.
@@ -459,7 +463,7 @@ class ConfigurationApiV35(HttpClient):
                    avatar: str = None,
                    max_chats_count: int = None,
                    groups: list = None,
-                   webhooks: dict = None,
+                   default_group_priority: str = None,
                    work_scheduler: dict = None,
                    timezone: str = None,
                    payload: dict = None,
@@ -472,7 +476,7 @@ class ConfigurationApiV35(HttpClient):
                 avatar (str): Avatar URL.
                 max_chats_count (int): Max. number of incoming chats that can be routed to the Bot.
                 groups (list): Groups the Bot belongs to.
-                webhooks (dict): Webhooks sent to the Bot.
+                default_group_priority (str): The default routing priority for a group without defined priority.
                 work_scheduler (dict): Work scheduler options to set for the new Bot.
                 timezone (str): The time zone in which the Bot's work scheduler should operate.
                 payload (dict): Custom payload to be used as request's data.
@@ -897,18 +901,18 @@ class ConfigurationApiV35(HttpClient):
                                  json=payload,
                                  headers=headers)
 
-    def list_group_properties(self,
-                              id: int = None,
-                              namespace: str = None,
-                              name_prefix: str = None,
-                              payload: dict = None,
-                              headers: dict = None) -> httpx.Response:
-        ''' Returns the properties set within a group.
+    def list_groups_properties(self,
+                               namespace: str = None,
+                               name_prefix: str = None,
+                               group_ids: List[int] = None,
+                               payload: dict = None,
+                               headers: dict = None) -> httpx.Response:
+        ''' Returns the properties set within multiple groups.
 
             Args:
-                id (int): ID of the group you retrieve properties from.
                 namespace (str): Properties namespace.
                 name_prefix (str): Properties name prefix.
+                group_ids (List[int]): IDs of the groups to filter the properties by.
                 payload (dict): Custom payload to be used as request's data.
                                 It overrides all other parameters provided for the method.
                 headers (dict): Custom headers to be used with session headers.
@@ -921,7 +925,7 @@ class ConfigurationApiV35(HttpClient):
         '''
         if payload is None:
             payload = prepare_payload(locals())
-        return self.session.post(f'{self.api_url}/list_group_properties',
+        return self.session.post(f'{self.api_url}/list_groups_properties',
                                  json=payload,
                                  headers=headers)
 
@@ -1241,57 +1245,8 @@ class ConfigurationApiV35(HttpClient):
                                  json=payload,
                                  headers=headers)
 
-
 # Other
 
-    def get_license_id(self,
-                       organization_id: str = None,
-                       params: dict = None,
-                       headers: dict = None) -> httpx.Response:
-        ''' Returns license ID by given organization ID.
-
-            Args:
-                organization_id (str): Organization ID to get license ID for.
-                params (dict): Custom params to be used in request's query string.
-                                It overrides all other parameters provided for the method.
-                headers (dict): Custom headers to be used with session headers.
-                                They will be merged with session-level values that are set,
-                                however, these method-level parameters will not be persisted across requests.
-
-            Returns:
-                httpx.Response: The Response object from `httpx` library,
-                                which contains a server's response to an HTTP request.
-        '''
-        if params is None:
-            params = prepare_payload(locals())
-        return self.session.get(f'{self.api_url}/get_license_id',
-                                params=params,
-                                headers=headers)
-
-    def get_organization_id(self,
-                            license_id: int = None,
-                            params: dict = None,
-                            headers: dict = None) -> httpx.Response:
-        ''' Returns organization ID by given license ID.
-
-            Args:
-                license_id (int): License ID to get organization ID for.
-                params (dict): Custom params to be used in request's query string.
-                                It overrides all other parameters provided for the method.
-                headers (dict): Custom headers to be used with session headers.
-                                They will be merged with session-level values that are set,
-                                however, these method-level parameters will not be persisted across requests.
-
-            Returns:
-                httpx.Response: The Response object from `httpx` library,
-                                which contains a server's response to an HTTP request.
-        '''
-        if params is None:
-            params = prepare_payload(locals())
-        return self.session.get(f'{self.api_url}/get_organization_id',
-                                params=params,
-                                headers=headers)
-
     def list_channels(self,
                       payload: dict = None,
                       headers: dict = None) -> httpx.Response:
@@ -1312,10 +1267,10 @@ class ConfigurationApiV35(HttpClient):
                                  json=payload,
                                  headers=headers)
 
-    def check_product_limits(self,
-                             plan: str = None,
-                             payload: dict = None,
-                             headers: dict = None) -> httpx.Response:
+    def check_product_limits_for_plan(self,
+                                      plan: str = None,
+                                      payload: dict = None,
+                                      headers: dict = None) -> httpx.Response:
         ''' Checks product limits for plans.
             Args:
                 plan (str): License plan to check limit for.
@@ -1334,3 +1289,197 @@ class ConfigurationApiV35(HttpClient):
             f'{self.api_url}/check_product_limits_for_plan',
             json=payload,
             headers=headers)
+
+    def get_product_source(self,
+                           payload: dict = None,
+                           headers: dict = None) -> httpx.Response:
+        ''' Retrieves the source parameters that were passed when activating the LiveChat product.
+            Args:
+                payload (dict): Custom payload to be used as request's data.
+                                It overrides all other parameters provided for the method.
+                headers (dict): Custom headers to be used with session headers.
+                                They will be merged with session-level values that are set,
+                                however, these method-level parameters will not be persisted across requests.
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.get(f'{self.api_url}/get_product_source',
+                                json=payload,
+                                headers=headers)
+
+
+# Batch requests
+
+    def batch_create_agents(self,
+                            requests: list = None,
+                            payload: dict = None,
+                            headers: dict = None) -> httpx.Response:
+        ''' Batch method for `create_agent`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_create_agents',
+                                 json=payload,
+                                 headers=headers)
+
+    def batch_delete_agents(self,
+                            requests: list = None,
+                            payload: dict = None,
+                            headers: dict = None) -> httpx.Response:
+        ''' Batch method for `delete_agent`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_delete_agents',
+                                 json=payload,
+                                 headers=headers)
+
+    def batch_update_agents(self,
+                            requests: list = None,
+                            payload: dict = None,
+                            headers: dict = None) -> httpx.Response:
+        ''' Batch method for `update_agent`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_update_agents',
+                                 json=payload,
+                                 headers=headers)
+
+    def batch_approve_agents(self,
+                             requests: list = None,
+                             payload: dict = None,
+                             headers: dict = None) -> httpx.Response:
+        ''' Batch method for `approve_agent`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_approve_agents',
+                                 json=payload,
+                                 headers=headers)
+
+    def batch_suspend_agents(self,
+                             requests: list = None,
+                             payload: dict = None,
+                             headers: dict = None) -> httpx.Response:
+        ''' Batch method for `suspend_agent`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_suspend_agents',
+                                 json=payload,
+                                 headers=headers)
+
+    def batch_unsuspend_agents(self,
+                               requests: list = None,
+                               payload: dict = None,
+                               headers: dict = None) -> httpx.Response:
+        ''' Batch method for `unsuspend_agent`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_unsuspend_agents',
+                                 json=payload,
+                                 headers=headers)
+
+    def batch_create_bots(self,
+                            requests: list = None,
+                            payload: dict = None,
+                            headers: dict = None) -> httpx.Response:
+        ''' Batch method for `create_bot`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_create_bots',
+                                 json=payload,
+                                 headers=headers)
+
+    def batch_delete_bots(self,
+                            requests: list = None,
+                            payload: dict = None,
+                            headers: dict = None) -> httpx.Response:
+        ''' Batch method for `delete_bot`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_delete_bots',
+                                 json=payload,
+                                 headers=headers)
+
+    def batch_update_bots(self,
+                            requests: list = None,
+                            payload: dict = None,
+                            headers: dict = None) -> httpx.Response:
+        ''' Batch method for `update_bot`.
+
+            Args:
+                requests (list): Array of Request objects of corresponding non-batch method.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/batch_update_bots',
+                                 json=payload,
+                                 headers=headers)
