@@ -283,7 +283,7 @@ class ReportsApiV35(HttpClient):
         '''
         if payload is None:
             payload = prepare_payload(locals())
-        return self.session.post(f'{self.api_url}/agents/response_time',
+        return self.session.post(f'{self.api_url}/chats/response_time',
                                  json=payload,
                                  headers=headers)
 
@@ -313,7 +313,7 @@ class ReportsApiV35(HttpClient):
         '''
         if payload is None:
             payload = prepare_payload(locals())
-        return self.session.post(f'{self.api_url}/agents/first_response_time',
+        return self.session.post(f'{self.api_url}/chats/first_response_time',
                                  json=payload,
                                  headers=headers)
 
@@ -382,11 +382,11 @@ class ReportsApiV35(HttpClient):
 
 # Tags
 
-    def tags_chat_usage(self,
-                        timezone: str = None,
-                        filters: dict = None,
-                        payload: dict = None,
-                        headers: dict = None) -> httpx.Response:
+    def chat_usage(self,
+                   timezone: str = None,
+                   filters: dict = None,
+                   payload: dict = None,
+                   headers: dict = None) -> httpx.Response:
         ''' Shows the total number of chats marked with each tag.
 
         Args:
